@@ -68,13 +68,19 @@ medicare_levy <- function(income,
   
   income_share <- NULL
   
-  data.table(income = income, 
-             Spouse_income = Spouse_income,
-             fy_year = fy.year,
-             sapto = sapto.eligible, 
-             sato = sato, 
-             pto = pto,
-             family_status = family_status) %>%
+  # It is no faster in the case of single-length fy.year
+  # or sapto.eligble etc and then selecting the table as required. 
+  # if (AND(length(fy.year) == 1L,
+  #         AND(length(sapto.eligible) == 1L,
+  
+  input_with_parameters <-
+    data.table(income = income, 
+               Spouse_income = Spouse_income,
+               fy_year = fy.year,
+               sapto = sapto.eligible, 
+               sato = sato, 
+               pto = pto,
+               family_status = family_status) %>%
     # Assume spouse income is included irrespective of Partner_status
     # This appears to be the correct treatment (e.g. if the Partner dies 
     # before the end of the tax year, they would have status 0 but 
@@ -82,12 +88,10 @@ medicare_levy <- function(income,
     # (such as if the partner is in gaol) that are overlooked here.
     # 
     # Enhancement: family taxable income should exclude super lump sums.
-    .[ ,family_income := income + Spouse_income ] %>%
-    merge(medicare_tbl, 
-          by = c("fy_year", "sapto", "sato", "pto"),
-          sort = FALSE, 
-          all.x = TRUE) %>%
+    .[, family_income := income + Spouse_income ] %>%
+    medicare_tbl[., on = c("fy_year", "sapto", "sato", "pto")]
     
+  input_with_parameters %>%
     # Person who has spouse or dependants
     ## subs.8(5) of Act
     .[, lower_family_threshold := lower_family_threshold + n_dependants * lower_up_for_each_child] %>%
