@@ -1,25 +1,8 @@
 context("Aus pop qtr")
 
 test_that("Returns correct values", {
-  expect_equal(round(aus_pop_qtr("2000-Q1", allow.projections = FALSE, fertility = "high", mortality = "high.LifeExpectancy"), -4), 
-               18990000)
-  
-  x <- aus_pop_qtr("2030-Q1", allow.projections = TRUE, fertility = "high")
-  y <- aus_pop_qtr("2030-Q1", allow.projections = TRUE, fertility = "medium")
-  z <- aus_pop_qtr("2030-Q1", allow.projections = TRUE, fertility = "low")
-  
-  expect_gte(x, 
-             y)
-  
-  expect_lte(z, 
-             y)
-  
-  expect_warning(aus_pop_qtr("2030-Q1", allow.projections = FALSE, fertility = "high"))
-  
-  # Assumes population continues to grow!
-  expect_gte(suppressWarnings(aus_pop_qtr("2030-Q1", allow.projections = FALSE, fertility = "high")), 
-             24e6)
-  
+  expect_equal(aus_pop_qtr("2016-Q1"), 24122701)
+  expect_gte(aus_pop_qtr("2018-Q1"), 24122701)
   # by age
   
   expect_equivalent(grattan:::aust_pop_by_age_yearqtr, aus_pop_qtr_age(tbl = TRUE))
@@ -74,6 +57,10 @@ test_that("Rolls work as expected", {
 })
 
 test_that("Error handling", {
+  expect_error(aus_pop_qtr("2016 Q0"), "Entry 1 was not in the correct form")
+  expect_error(aus_pop_qtr(c("2016 Q0", "2016-Q2", "19999")), "Entries 1 and 3 were not in the correct form")
+  expect_error(aus_pop_qtr(c("2016 Q0", "2016 q1")), "Entries 1 and 2 were not in the correct form")
+  
   expect_error(aus_pop_qtr_age(date = "2015-01-01"))
   expect_error(aus_pop_qtr_age(age = "45"))
   expect_error(aus_pop_qtr_age(age = 101))
