@@ -1,7 +1,10 @@
 context("Tax collections")
 
 test_that("income_tax collections in 2003-04 match final budget outcome by 1%", {
-  skip_if_not_installed("taxstats") 
+  skip_if_not_installed("taxstats", minimum_version = package_version("0.0.5")) 
+  skip_on_cran()
+  skip_on_appveyor()
+  library(taxstats)
   # http://www.budget.gov.au/2003-04/fbo/download/FBO_2003_04.pdf
   final_budget_outcome_0304 <- 98.779 * 1e9
   collections_0304 <- sum(income_tax(sample_file_0304[["Taxable_Income"]], 
@@ -14,7 +17,10 @@ test_that("income_tax collections in 2003-04 match final budget outcome by 1%",
 })
 
 test_that("income_tax collections in 2006-07 match final budget outcome by 1%", {
-  skip_if_not_installed("taxstats") 
+  skip_if_not_installed("taxstats", minimum_version = package_version("0.0.5")) 
+  skip_on_cran()
+  skip_on_appveyor()
+  library(taxstats)
   # http://www.budget.gov.au/2006-07/fbo/download/FBO_2006-07.pdf
   final_budget_outcome_0607 <- 117.614 * 1e9
   collections_0607 <- sum(income_tax(sample_file_0607[["Taxable_Income"]], 
@@ -26,10 +32,12 @@ test_that("income_tax collections in 2006-07 match final budget outcome by 1%",
             0.01)
 })
 
-context("Projected tax collections")
 
 test_that("Projections match collections", {
-  skip_if_not_installed("taxstats") 
+  skip_if_not_installed("taxstats", minimum_version = package_version("0.0.5")) 
+  skip_on_cran()
+  skip_on_appveyor()
+  library(taxstats)
   collections_1314_proj.over.actual <- 
     sample_file_1213 %>%
     # ABS: 166,027 million. Cat 5506
